@@ -25,7 +25,7 @@ documentation and/or software.
 
 #include <config.h>
 
-#if defined(WITH_LDAP) || defined(WITH_MYSQL)
+#if defined(WITH_LDAP) || defined(WITH_MYSQL) || defined(WITH_PGSQL)
 
 #include "ftpd.h"
 #include "crypto.h"
@@ -322,4 +322,6 @@ static void Decode(crypto_uint4 * output, const unsigned char *input,
 
 #endif
 
+#else
+extern signed char v6ready;
 #endif
