@@ -14,7 +14,7 @@
 
 #include <config.h>
 
-#if defined(WITH_LDAP) || defined(WITH_MYSQL)
+#if defined(WITH_LDAP) || defined(WITH_MYSQL) || defined(WITH_PGSQL)
 
 #include "ftpd.h"
 #include "crypto.h"
@@ -241,4 +241,6 @@ void SHA1Final(unsigned char digest[20], SHA1_CTX * context)
 #endif
 }
 
+#else
+extern signed char v6ready;
 #endif
