@@ -1,6 +1,6 @@
 #include <config.h>
 
-#if defined(WITH_LDAP) || defined(WITH_MYSQL)
+#if defined(WITH_LDAP) || defined(WITH_MYSQL) || defined(WITH_PGSQL)
 
 #include "ftpd.h"
 #include "crypto.h"
@@ -274,4 +274,6 @@ char *crypto_hash_smd5(const char *string, const char *stored)
     return decoded;
 }
 
+#else
+extern signed char v6ready;
 #endif
