@@ -137,7 +137,8 @@ int fakesnprintf_vsnprintf(char * const str_, const size_t size_,
             case '.':
                 format++;
                 hasmaxlen = 1U;
-                while (*format >= '0' && *format <= '9') {
+                while ((unsigned char) *format >= '0' && 
+                       (unsigned char) *format <= '9') {
                     maxlen *= 10U;
                     maxlen += (*format - '0');
                     format++;
@@ -149,7 +150,8 @@ int fakesnprintf_vsnprintf(char * const str_, const size_t size_,
                     padlen *= 10U;
                     padlen += *format - '0';
                     format++;
-                } while (*format >= '0' && *format <= '9');
+                } while ((unsigned char) *format >= '0' && 
+                         (unsigned char) *format <= '9');
                 goto breakpoint_nextspecial_noinc;
             case '-':
                 minuspad++;
@@ -164,7 +166,7 @@ int fakesnprintf_vsnprintf(char * const str_, const size_t size_,
 
                 pnt = va_arg(va, const char *);
                 if (pnt == NULL) {
-                    pnt = "(NULL)";
+                    pnt = "<NULL>";
                 }
                 fakesnprintf_addstr(&str, &size, pnt, maxlen, padlen,
                                     zero, minuspad);
