@@ -146,7 +146,7 @@ static char *revealextraspc(char * const s_)
     if (s == NULL) {
         return s_;
     }
-    simplify(s);
+    simplify(s_);
     while (*s != 0U && isspace(*s)) {
         *s++ = '_';
     }
@@ -215,7 +215,7 @@ void parser(void)
         }
         if (n == (size_t) 0U) {
             nop:
-            addreply(500, "?");
+            addreply_noformat(500, "?");
             continue;
         }
 #ifdef SKIP_COMMAND_TRAILING_SPACES        
@@ -277,11 +277,11 @@ void parser(void)
             return;
         } else if (!strcmp(cmd, "syst")) {
             antiidle();
-            addreply(215, "UNIX Type: L8");
+            addreply_noformat(215, "UNIX Type: L8");
             goto wayout;
         } else if (!strcmp(cmd, "auth") || !strcmp(cmd, "adat")) {
             /* RFC 2228 Page 5 Authentication/Security mechanism (AUTH) */
-            addreply(502, MSG_AUTH_UNIMPLEMENTED);
+            addreply_noformat(502, MSG_AUTH_UNIMPLEMENTED);
         } else if (!strcmp(cmd, "type")) {
             antiidle();
             dotype(arg);
@@ -310,7 +310,7 @@ void parser(void)
 #endif            
         } else if (loggedin == 0) {            
             /* from this point, all commands need authentication */
-            addreply(530, MSG_NOT_LOGGED_IN);
+            addreply_noformat(530, MSG_NOT_LOGGED_IN);
             goto wayout;
         } else {
             if (!strcmp(cmd, "cwd") || !strcmp(cmd, "xcwd")) {
@@ -332,9 +332,9 @@ void parser(void)
                         STORAGE_FAMILY(ctrlconn) == AF_INET6))) {
                 if (!strcasecmp(arg, "all")) {
                     epsv_all = 1;
-                    addreply(220, MSG_ACTIVE_DISABLED);
+                    addreply_noformat(220, MSG_ACTIVE_DISABLED);
                 } else if (!strcmp(arg, "2") && !v6ready) {
-                    addreply(522, MSG_ONLY_IPV4);
+                    addreply_noformat(522, MSG_ONLY_IPV4);
                 } else {
                     dopasv(1);
                 }
@@ -352,14 +352,14 @@ void parser(void)
                 if (*arg != 0) {
                     doretr(arg);
                 } else {
-                    addreply(501, MSG_NO_FILE_NAME);
+                    addreply_noformat(501, MSG_NO_FILE_NAME);
                 }
             } else if (!strcmp(cmd, "rest")) {
                 antiidle();
                 if (*arg != 0) {
                     dorest(arg);
                 } else {
-                    addreply(501, MSG_NO_RESTART_POINT);
+                    addreply_noformat(501, MSG_NO_RESTART_POINT);
                     restartat = (off_t) 0;
                 }
                 goto wayout;
@@ -367,21 +367,21 @@ void parser(void)
                 if (*arg != 0) {
                     dodele(arg);
                 } else {
-                    addreply(501, MSG_NO_FILE_NAME);
+                    addreply_noformat(501, MSG_NO_FILE_NAME);
                 }
             } else if (!strcmp(cmd, "stor")) {
                 arg = revealextraspc(arg);
                 if (*arg != 0) {
                     dostor(arg, 0, autorename);
                 } else {
-                    addreply(501, MSG_NO_FILE_NAME);
+                    addreply_noformat(501, MSG_NO_FILE_NAME);
                 }
             } else if (!strcmp(cmd, "appe")) {
                 arg = revealextraspc(arg);
                 if (*arg != 0) {
                     dostor(arg, 1, 0);
                 } else {
-                    addreply(501, MSG_NO_FILE_NAME);
+                    addreply_noformat(501, MSG_NO_FILE_NAME);
                 }
 #ifndef MINIMAL
             } else if (!strcmp(cmd, "stou")) {
@@ -393,13 +393,13 @@ void parser(void)
                 if (*arg != 0) {
                     domkd(arg);
                 } else {
-                    addreply(501, MSG_NO_DIRECTORY_NAME);
+                    addreply_noformat(501, MSG_NO_DIRECTORY_NAME);
                 }
             } else if (!strcmp(cmd, "rmd") || !strcmp(cmd, "xrmd")) {
                 if (*arg != 0) {
                     dormd(arg);
                 } else {
-                    addreply(550, MSG_NO_DIRECTORY_NAME);
+                    addreply_noformat(550, MSG_NO_DIRECTORY_NAME);
                 }
 #endif
 #ifndef MINIMAL
@@ -409,7 +409,7 @@ void parser(void)
                     modern_listings = 0;
                     donlist(arg, 1);
                 } else {
-                    addreply(211, "http://www.pureftpd.org");
+                    addreply_noformat(211, "http://www.pureftpd.org");
                 }
 #endif
             } else if (!strcmp(cmd, "list")) {
@@ -433,7 +433,7 @@ void parser(void)
                 donlist(arg, 0);
 #endif
             } else if (!strcmp(cmd, "abor")) {
-                addreply(226, MSG_ABOR_SUCCESS);
+                addreply_noformat(226, MSG_ABOR_SUCCESS);
 #ifndef MINIMAL
             } else if (!strcmp(cmd, "site")) {
                 if ((sitearg = arg) != NULL) {
@@ -446,7 +446,7 @@ void parser(void)
                 }
                 if (!strcasecmp(arg, "idle")) {
                     if (sitearg == NULL || *sitearg == 0) {
-                        addreply(501, "SITE IDLE: " MSG_MISSING_ARG);
+                        addreply_noformat(501, "SITE IDLE: " MSG_MISSING_ARG);
                     } else {
                         unsigned long int i = 0;
 
@@ -454,7 +454,7 @@ void parser(void)
                         if (sitearg && *sitearg)
                             addreply(501, MSG_GARBAGE_FOUND " : %s", sitearg);
                         else if (i > MAX_SITE_IDLE)
-                            addreply(501, MSG_VALUE_TOO_LARGE);
+                            addreply_noformat(501, MSG_VALUE_TOO_LARGE);
                         else {
                             idletime = i;
                             addreply(200, MSG_IDLE_TIME, idletime);
@@ -476,7 +476,7 @@ void parser(void)
                     
                     parsechmod:
                     if (sitearg == NULL || *sitearg == 0) {
-                        addreply(501, "SITE CHMOD: " MSG_MISSING_ARG);
+                        addreply_noformat(501, "SITE CHMOD: " MSG_MISSING_ARG);
                         goto chmod_wayout;
                     }
                     sitearg2 = sitearg;
@@ -487,12 +487,12 @@ void parser(void)
                         sitearg2++;
                     }                    
                     if (*sitearg2 == 0) {
-                        addreply(550, "SITE CHMOD: " MSG_NO_FILE_NAME);
+                        addreply_noformat(550, "SITE CHMOD: " MSG_NO_FILE_NAME);
                         goto chmod_wayout;
                     }
                     mode = (mode_t) strtoul(sitearg, NULL, 8);
                     if (mode > (mode_t) 07777) {
-                        addreply(501, "SITE CHMOD: " MSG_BAD_CHMOD);
+                        addreply_noformat(501, "SITE CHMOD: " MSG_BAD_CHMOD);
                         goto chmod_wayout;
                     }
                     dochmod(sitearg2, mode);
@@ -505,7 +505,7 @@ void parser(void)
                     } else {
                         register const char *alias;
                         
-                        if ((alias = lookup_alias(sitearg)) == NULL) {
+                        if ((alias = lookup_alias(sitearg)) != NULL) {
                             addreply(214, MSG_ALIASES_ALIAS, sitearg, alias);
                         } else {
                             addreply(502, MSG_ALIASES_UNKNOWN, sitearg);
@@ -515,7 +515,7 @@ void parser(void)
                 } else if (*arg != 0) {
                     addreply(500, "SITE %s " MSG_UNKNOWN_EXTENSION, arg);
                 } else {
-                    addreply(500, "SITE: " MSG_MISSING_ARG);
+                    addreply_noformat(500, "SITE: " MSG_MISSING_ARG);
                 }
 #endif
             } else if (!strcmp(cmd, "mdtm")) {
@@ -531,17 +531,17 @@ void parser(void)
                 if (*arg != 0) {
                     dornfr(arg);
                 } else {
-                    addreply(550, MSG_NO_FILE_NAME);
+                    addreply_noformat(550, MSG_NO_FILE_NAME);
                 }
             } else if (!strcmp(cmd, "rnto")) {
                 arg = revealextraspc(arg);
                 if (*arg != 0) {
                     dornto(arg);
                 } else {
-                    addreply(550, MSG_NO_FILE_NAME);
+                    addreply_noformat(550, MSG_NO_FILE_NAME);
                 }
             } else {
-                addreply(500, MSG_UNKNOWN_COMMAND);
+                addreply_noformat(500, MSG_UNKNOWN_COMMAND);
             }
         }
         noopidle = (time_t) -1;
