@@ -53,11 +53,11 @@ static volatile sig_atomic_t stop_server;
 static const char *standalone_port = DEFAULT_FTP_PORT_S;
 static const char *standalone_ip;
 static volatile unsigned int nb_children;
-static int listenfd = -1;
+static volatile int listenfd = -1;
 #endif
 
 struct reply {
-    struct reply *prev;
+    struct reply *next;
     char line[1];
 };
 
@@ -77,7 +77,7 @@ static const char *GETOPT_OPTIONS =
 #ifdef QUOTAS
     "n:"
 #endif
-#if defined(WITH_UPLOAD_SCRIPT) && !defined(NON_ROOT_FTP)
+#if defined(WITH_UPLOAD_SCRIPT)
     "o"
 #endif
 #ifdef WITH_ALTLOG
@@ -94,7 +94,7 @@ static const char *GETOPT_OPTIONS =
 #ifdef THROTTLING
     "t:T:"
 #endif
-    "u:U:V:wWxXz";
+    "u:U:V:wWxXzZ";
 
 #ifndef NO_GETOPT_LONG    
 static struct option long_options[] = {
@@ -135,7 +135,7 @@ static struct option long_options[] = {
 # ifdef QUOTAS
     { "quota", 1, NULL, 'n' },
 # endif
-# if defined(WITH_UPLOAD_SCRIPT) && !defined(NON_ROOT_FTP)
+# if defined(WITH_UPLOAD_SCRIPT)
     { "uploadscript", 0, NULL, 'o' },
 # endif
 # ifdef WITH_ALTLOG
@@ -162,7 +162,8 @@ static struct option long_options[] = {
     { "allowanonymousfxp", 0, NULL, 'W' },
     { "prohibitdotfileswrite", 0, NULL, 'x' },
     { "prohibitdotfilesread", 0, NULL, 'X' },
-    { "allowdotfiles", 0, NULL, 'z' },        
+    { "allowdotfiles", 0, NULL, 'z' },
+    { "customerproof", 0, NULL, 'Z' },
     { NULL, 0, NULL, 0 }
 };
 
@@ -256,4 +257,11 @@ static struct passwd *fakegetpwnam(const char * const name);
 # define WIN32_ANON_DIR "/ftp"
 #endif
 
+#ifdef PROBE_RANDOM_AT_RUNTIME
+static const char *random_device;
+#endif
+
+static struct reply *firstreply;
+static struct reply *lastreply;
+
 #endif
