@@ -243,6 +243,7 @@ static char *pw_mysql_getquery(MYSQL * const id_sql_server,
         goto bye;
     }
     if (mysql_real_query(id_sql_server, query, strlen(query)) != 0) {
+        logfile(LOG_WARNING, MSG_SQL_WRONG_PARMS " : [%s]", query);
         goto bye;
     }
     if (mysql_field_count(id_sql_server) != 1) {
@@ -467,7 +468,7 @@ void pw_mysql_check(AuthResult * const result,
     if (result->gid <= (gid_t) 0) {
         struct group *gr;
         
-        if ((gr = getgrnam(gid)) == NULL || gr->gr_gid <= (gid_t) 0) {
+        if ((gr = getgrnam(gid)) == NULL || (gid_t) gr->gr_gid <= (gid_t) 0) {
             goto bye;
         }
         result->gid = gr->gr_gid;
