@@ -69,7 +69,7 @@ static char *my_strtok2(char *str, const char delim)
 /* Check whether an IP address matches a pattern. 1 = match 0 = nomatch */
 
 static int access_ip_match(const struct sockaddr_storage * const sa,
-                           const char * pattern)
+                           char * pattern)
 {
     unsigned int ip0, ip1, ip2, ip3;
     unsigned int netbits;
@@ -77,6 +77,7 @@ static int access_ip_match(const struct sockaddr_storage * const sa,
     unsigned long mask;
     unsigned long saip;
     const unsigned char *saip_raw;
+    char *comapoint;
         
     if (*pattern == 0) {
         return 1;
@@ -84,26 +85,57 @@ static int access_ip_match(const struct sockaddr_storage * const sa,
     if (STORAGE_FAMILY(*sa) != AF_INET) {
         return 0;                      /* TODO: IPv6 */
     }
-    for (;;) {
+    do {
+        if ((comapoint = strchr(pattern, ',')) != NULL) {
+            *comapoint = 0;
+        }
         if (sscanf(pattern, "%u.%u.%u.%u/%u",    /* IPv4 */
                    &ip0, &ip1, &ip2, &ip3, &netbits) == 5) {
-            if (STORAGE_FAMILY(*sa) != AF_INET || netbits == 0) {
+            ipcheck:
+            if (STORAGE_FAMILY(*sa) != AF_INET || netbits == 0U) {
                 return -1;
             }
             ip = (ip0 << 24) | (ip1 << 16) | (ip2 << 8) | ip3;
-            mask = ~((0x80000000 >> (netbits - 1)) - 1);
+            ipcheck_ipdone:
+            mask = ~((0x80000000 >> (netbits - 1U)) - 1U);
             saip_raw = (const unsigned char *) &(STORAGE_SIN_ADDR(*sa));
             saip = (saip_raw[0] << 24) | (saip_raw[1] << 16) |
                 (saip_raw[2] << 8) | saip_raw[3];
             if ((ip & mask) == (saip & mask)) {
                 return 1;
             }
-        }        
-        if ((pattern = strchr(pattern, ',')) == NULL || pattern[1] == 0) {
+        } else if (sscanf(pattern, "%u.%u.%u.%u",
+                          &ip0, &ip1, &ip2, &ip3) == 4) {
+            netbits = 32U;
+            goto ipcheck;
+        } else {
+            struct addrinfo hints, *res;
+            int on;
+
+            memset(&hints, 0, sizeof hints);
+            hints.ai_family = AF_INET;
+            hints.ai_addr = NULL;
+            if ((on = getaddrinfo(pattern, NULL, &hints, &res)) != 0 ||
+                res->ai_family != AF_INET) {
+                logfile(LOG_WARNING, "puredb: [%s] => [%d]", pattern, on);
+            } else {
+                const unsigned char * const ip_raw =
+                    (const unsigned char *) &
+                    (((const struct sockaddr_in *) 
+                      (res->ai_addr))->sin_addr.s_addr);
+                
+                ip = (ip_raw[0] << 24) | (ip_raw[1] << 16) |
+                    (ip_raw[2] << 8) | ip_raw[3];
+                netbits = 32U;
+                goto ipcheck_ipdone;
+            }
+        }
+        if (comapoint == NULL) {
             break;
         }
-        pattern++;        
-    }
+        *comapoint = ',';
+        pattern = comapoint + 1;
+    } while (*pattern != 0);
         
     return 0;
 }
@@ -111,8 +143,7 @@ static int access_ip_match(const struct sockaddr_storage * const sa,
 /* IP check. 0 = ok, -1 = denied */
 
 static int access_ip_check(const struct sockaddr_storage * const sa,
-                           const char * const allow, 
-                           const char * const deny)
+                           char * const allow, char * const deny)
 {
     if (sa == NULL) {
         return 0;
@@ -171,8 +202,8 @@ static int pw_puredb_parseline(char *line, const char * const pwd,
                                const struct sockaddr_storage * const peer,
                                AuthResult * const result)
 {
-    const char *allow_local_ip, *deny_local_ip;
-    const char *allow_remote_ip, *deny_remote_ip;
+    char *allow_local_ip, *deny_local_ip;
+    char *allow_remote_ip, *deny_remote_ip;
     const char *time_restrictions;
     
     if ((line = my_strtok2(line, *PW_LINE_SEP)) == NULL || *line == 0) {   /* pwd */
