@@ -231,6 +231,12 @@ static int listfile(const FileInfo * const fi,  const char *name)
         st.st_gid = fi->gid;
         name = FI_NAME(fi);
     }
+#if defined(WITH_VIRTUAL_CHROOT) && defined(S_IFLNK) && defined(S_IFDIR)
+    if (S_ISLNK(st.st_mode) && name[0] == '.' && name[1] == '.' && name[2] == 0) {
+        st.st_mode &= ~S_IFLNK;
+        st.st_mode |= S_IFDIR;
+    }  /* Hack to please some Windows client that dislike ../ -> ../ */
+#endif
     t = localtime((time_t *) & st.st_mtime);
     if (!t) {
         die(421, LOG_ERR, "localtime()");
@@ -370,7 +376,7 @@ static int listfile(const FileInfo * const fi,  const char *name)
             addfile(alloca_nameline, suffix);
             ALLOCA_FREE(alloca_nameline);            
         }                    /* hide non-downloadable files */
-    } else {
+    } else {        
         if (S_ISREG(st.st_mode) ||
             S_ISDIR(st.st_mode) || S_ISLNK(st.st_mode)) {
             addfile(name, suffix);
