@@ -5,11 +5,7 @@
 #define GLOB_ABEND GLOB_ABORTED
 #endif
 
-#ifdef PAGE_SIZE
-# define CHUNK_SIZE ((size_t) PAGE_SIZE)
-#else
-# define CHUNK_SIZE ((size_t) 4096U)
-#endif
+#define CHUNK_SIZE page_size
 
 static int colwidth;
 static int filenames;
