@@ -53,6 +53,10 @@
 # define MESSAGES_LOCALE "sv_SE"
 # include "messages_sv.h"
 
+#elif defined(MESSAGES_NO)
+# define MESSAGES_LOCALE "no_NO"
+# include "messages_no.h"
+
 #else
 # define MESSAGES_LOCALE "en_GB"
 # include "messages_en.h"
