@@ -208,8 +208,8 @@
 #define MSG_QUOTA_SIZE "%llu Kbytes utilizados (%d%%) - autorizados: %llu Kb"
 #define MSG_QUOTA_EXCEEDED "Cuota excedida : %s no ser guardado"
 #define MSG_AUTH_UNKNOWN "Mtodo de autentificacin desconocido"
-#define MSG_PDB_BROKEN "Unable to read the indexed puredb file (or old format detected) - Try pure-pw mkdb"
-#define MSG_ALIASES_ALIAS "%s is an alias for %s."
-#define MSG_ALIASES_UNKNOWN "Unknown alias %s."
-#define MSG_ALIASES_BROKEN_FILE "Damaged aliases file"
-#define MSG_ALIASES_LIST "The following aliases are available :"
+#define MSG_PDB_BROKEN "No se puede leer el fichero indexado puredb (o formato antiguo detectado) - Prueba a ejecutar pure-pw mkdb"
+#define MSG_ALIASES_ALIAS "%s es un alias para %s."
+#define MSG_ALIASES_UNKNOWN "Alias desconocido %s."
+#define MSG_ALIASES_BROKEN_FILE "Fichero de alias daado"
+#define MSG_ALIASES_LIST "Los siguientes alias estn disponibles :"
