@@ -17,7 +17,7 @@
 #define MSG_IS_YOUR_CURRENT_LOCATION "is uw huidige locatie"
 #define MSG_NOT_LOGGED_IN "U bent niet ingelogd"
 #define MSG_AUTH_UNIMPLEMENTED "Beveiligings uitbreidingen zijn niet opgenomen"
-#define MSG_NO_FILE_NAME "Geen file naam"
+#define MSG_NO_FILE_NAME "Geen bestands naam"
 #define MSG_NO_DIRECTORY_NAME "Geen directory naam"
 #define MSG_NO_RESTART_POINT "Geen nieuw beginpunt"
 #define MSG_ABOR_SUCCESS "Als u dit ziet is ABOR geslaagd"
@@ -33,7 +33,7 @@
 #define MSG_TIMEOUT_NOOP "Onderbreking (geen activiteit gedurende %lu seconden)"
 #define MSG_TIMEOUT_DATA "Onderbreking (geen nieuwe gegevens gedurende %lu seconden)"
 #define MSG_SLEEPING "Zzz..."
-#define MSG_ALREADY_LOGGED "U was reeds ingelogd!"
+#define MSG_ALREADY_LOGGED "U bent reeds ingelogd!"
 #define MSG_ANY_PASSWORD "Elk willekeurig wachtwoord is goed"
 #define MSG_ANONYMOUS_LOGGED "Anonieme gebruiker is ingelogd"
 #define MSG_ANONYMOUS_LOGGED_VIRTUAL "Anonieme gebruiker is ingelogd in de virtuele FTP"
@@ -75,7 +75,7 @@
 #define MSG_CNX_PORT "Bezig te verbinden met poort %d"
 #define MSG_ANON_CANT_MKD "Sorry, anonieme gebruikers kunnen geen directories aanmaken"
 #define MSG_ANON_CANT_RMD "Sorry, anonieme gebruikers kunnen geen directories verwijderen"
-#define MSG_ANON_CANT_RENAME "Anonieme gebruikers kunnen geen files verplaatsen/herbenoemen"
+#define MSG_ANON_CANT_RENAME "Anonieme gebruikers kunnen geen bestanden verplaatsen/herbenoemen"
 #define MSG_ANON_CANT_CHANGE_PERMS "Anonieme gebruikers kunnen geen permissies veranderen"
 #define MSG_GLOB_NO_MEMORY "Niet genoeg geheugen tijdens globbing van %s"
 #define MSG_PROBABLY_DENIED "(Dit betekent schijnbaar \"Hiervoor is toestemming nodig\")"
@@ -84,24 +84,24 @@
 #define MSG_CHMOD_FAILED "Kon de permissies op %s niet veranderen"
 #define MSG_CHMOD_SUCCESS "Permissies veranderd op %s"
 #define MSG_CHMOD_TOTAL_FAILURE "Sorry, maar ik kon geen enkele permissie veranderen"
-#define MSG_ANON_CANT_DELETE "Anonieme gebruikers kunnen geen files wissen"
-#define MSG_ANON_CANT_OVERWRITE "Anonieme gebruikers kunnen geen bestaande files overschrijven."
+#define MSG_ANON_CANT_DELETE "Anonieme gebruikers kunnen geen bestanden wissen"
+#define MSG_ANON_CANT_OVERWRITE "Anonieme gebruikers kunnen geen bestaande bestanden overschrijven."
 #define MSG_DELE_FAILED "Kon %s niet wissen"
 #define MSG_DELE_SUCCESS "%s gewist"
-#define MSG_DELE_TOTAL_FAILURE "Geen file gewist"
+#define MSG_DELE_TOTAL_FAILURE "Geen bestand gewist"
 #define MSG_LOAD_TOO_HIGH \
     "De belasting was %3.2f toen u verbinding kreeg. Wij staan geen\n" \
         "downloads toe door anonieme gebruikers bij zo'n hoge belasting.\n" \
         "Uploaden is altijd toegestaan."
 #define MSG_OPEN_FAILURE "Kan %s niet openen"
-#define MSG_OPEN_FAILURE2 "Kan die file niet openen"
-#define MSG_STAT_FAILURE "Kan die filegrootte niet vinden"
-#define MSG_STAT_FAILURE2 "Kan niet kijken of die file bestaat"
-#define MSG_REST_TOO_LARGE_FOR_FILE "Opnieuw opgestart offset %lld is te groot voor file grootte %lld."
+#define MSG_OPEN_FAILURE2 "Kan dat bestand niet openen"
+#define MSG_STAT_FAILURE "Kan die bestandsgrootte niet vinden"
+#define MSG_STAT_FAILURE2 "Kan niet kijken of dat bestand bestaat"
+#define MSG_REST_TOO_LARGE_FOR_FILE "Opnieuw opgestart offset %lld is te groot voor bestand grootte %lld."
 #define MSG_REST_RESET "Opnieuw opgestart, offset is weer op 0 gezet"
-#define MSG_NOT_REGULAR_FILE "Ik kan alleen standaard files herstellen"
+#define MSG_NOT_REGULAR_FILE "Ik kan alleen standaard bestanden herstellen"
 #define MSG_NOT_MODERATED \
-    "Deze file is door een anonieme gebruiker ge-upload. Er is door de \n" \
+    "Dit bestand is door een anonieme gebruiker ge-upload. Er is door de \n" \
         "site beheerder nog geen toestemming gegegeven om die te downloaden.\n"
 #define MSG_RATIO_DENIAL \
     "Het spijt me, maar de upload/download verhouding is %u:%u .\n" \
@@ -113,8 +113,8 @@
 #define MSG_ABORTED "Overdracht afgebroken"
 #define MSG_DATA_WRITE_FAILED "Fout tijdens schrijven naar data verbinding"
 #define MSG_DATA_READ_FAILED "Fout tijdens lezen van data verbinding "
-#define MSG_MMAP_FAILED "Onmogelijk de file in het geheugen te plaatsen"
-#define MSG_WRITE_FAILED "Fout tijdens schrijven naar file"
+#define MSG_MMAP_FAILED "Onmogelijk het bestand in het geheugen te plaatsen"
+#define MSG_WRITE_FAILED "Fout tijdens schrijven naar bestand"
 #define MSG_TRANSFER_RATE_M "%.3f seconden (hier gemeten), %.2f Mbytes per seconde"
 #define MSG_TRANSFER_RATE_K "%.3f seconden (hier gemeten), %.2f Kbytes per seconde"
 #define MSG_TRANSFER_RATE_B "%.3f seconden (hier gemeten), %.2f bytes per seconde"
@@ -126,14 +126,14 @@
 #define MSG_REST_ASCII_WORKAROUND "We beginnen opnieuw bij %lld. Maar we zijn in ASCII mode"
 #define MSG_REST_SUCCESS "We beginnen opnieuw bij %lld"
 #define MSG_SANITY_DIRECTORY_FAILURE "Verboden directory naam"
-#define MSG_SANITY_FILE_FAILURE "Verboden file naam: %s"
+#define MSG_SANITY_FILE_FAILURE "Verboden bestandsnaam: %s"
 #define MSG_MKD_FAILURE "Kan geen directory aanmaken"
 #define MSG_MKD_SUCCESS "De directory is met succes aangemaakt"
 #define MSG_RMD_FAILURE "Kan de directory niet verwijderen"
 #define MSG_RMD_SUCCESS "De directory is verwijderd"
 #define MSG_TIMESTAMP_FAILURE "Kan geen tijdsindicatie krijgen"
 #define MSG_MODE_ERROR "Alleen ASCII en binary modes worden ondersteund"
-#define MSG_CREATE_FAILURE "Niet mogelijk om een file aan te maken"
+#define MSG_CREATE_FAILURE "Niet mogelijk om een bestand aan te maken"
 #define MSG_ABRT_ONLY "ABRT is het enige geldige commando tijdens uploaden"
 #define MSG_UPLOAD_PARTIAL "gedeeltelijk ge-upload"
 #define MSG_REMOVED "verwijderd"
@@ -145,21 +145,21 @@
 #define MSG_STRU_FAILURE "Alleen F(ile) wordt ondersteund"
 #define MSG_MODE_FAILURE "S(tream) mode gebruiken a.u.b."
 #define MSG_RENAME_ABORT "Voorgaande naamsverandering wordt afgebroken"
-#define MSG_RENAME_RNFR_SUCCESS "RNFR geaccepteerd - file bestaat reeds, gereed voor bestemming"
-#define MSG_FILE_DOESNT_EXIST "Het spijt me, maar die file bestaat niet"
-#define MSG_RENAME_ALREADY_THERE "RENAME mislukt - doel file bestaat reeds"
+#define MSG_RENAME_RNFR_SUCCESS "RNFR geaccepteerd - bestand bestaat reeds, gereed voor bestemming"
+#define MSG_FILE_DOESNT_EXIST "Het spijt me, maar dat bestand bestaat niet"
+#define MSG_RENAME_ALREADY_THERE "RENAME mislukt - doelbestand  bestaat reeds"
 #define MSG_RENAME_NORNFR "RNFR is nodig, vr RNTO"
 #define MSG_RENAME_FAILURE "Herbenoemings/verplaatsings fout"
-#define MSG_RENAME_SUCCESS "File is met succes herbenoemd of verplaatst"
+#define MSG_RENAME_SUCCESS "Bestand is met succes hernoemd of verplaatst"
 #define MSG_NO_SUPERSERVER "Pure-ftpd binnen een super-server (zoals tcpserver) laten draaien"
 #define MSG_NO_FTP_ACCOUNT "Niet in staat om de 'ftp' account te vinden"
 #define MSG_CONF_ERR "Configuratie fout"
-#define MSG_NO_VIRTUAL_FILE "Virtual users file naam ontbreekt"
+#define MSG_NO_VIRTUAL_FILE "Virtual users bestandsnaam ontbreekt"
 #define MSG_ILLEGAL_THROTTLING "Niet toegestane waarde voor throttling"
 #define MSG_ILLEGAL_TRUSTED_GID "Niet toegestane trusted gid voor chroot"
 #define MSG_ILLEGAL_USER_LIMIT "Niet toegestane gebruikers-limiet"
 #define MSG_ILLEGAL_FACILITY "Onbekende facility naam"
-#define MSG_ILLEGAL_CONFIG_FILE_LDAP "Ongeldige LDAP configuratie file"
+#define MSG_ILLEGAL_CONFIG_FILE_LDAP "Ongeldige LDAP configuratiebestand"
 #define MSG_ILLEGAL_LOAD_LIMIT "Niet toegestane load limiet"
 #define MSG_ILLEGAL_PORTS_RANGE "Niet toegestaan poorten bereik"
 #define MSG_ILLEGAL_LS_LIMITS "Niet toegestane 'ls' limieten"
@@ -167,7 +167,7 @@
 #define MSG_ILLEGAL_RATIO "Niet toegestane upload/download verhouding"
 #define MSG_ILLEGAL_UID_LIMIT "Niet toegestane uid limiet"
 #define MSG_ILLEGAL_OPTION "Onbekende run-time optie"
-#define MSG_LDAP_MISSING_BASE "Ontbrekende LDAPBaseDN in de LDAP configuratie file"
+#define MSG_LDAP_MISSING_BASE "Ontbrekende LDAPBaseDN in de LDAP configuratiebestand "
 #define MSG_LDAP_WRONG_PARMS "Verkeerde LDAP parameters"
 #define MSG_NEW_CONNECTION "Nieuwe verbinding vanaf %s"
 #define MSG_WELCOME_TO "Welkom bij"
@@ -192,7 +192,7 @@
 #define MSG_ANONYMOUS_ANY_PASSWORD "Elk willekeurig wachtwoord is goed"
 #define MSG_MAX_USERS_IP "Teveel verbindingen (%lu) vanaf dit IP"
 #define MSG_ACTIVE_DISABLED "Active mode is uitgeschakeld"
-#define MSG_TRANSFER_SUCCESSFUL "File overdracht was succesvol"
+#define MSG_TRANSFER_SUCCESSFUL "Bestand overdracht was succesvol"
 #define MSG_NO_DISK_SPACE "Schijf is vol - later uploaden a.u.b."
 #define MSG_OUT_OF_MEMORY "Geen geheugen meer!"
 #define MSG_ILLEGAL_TRUSTED_IP "Ilegaal IP adres"
@@ -204,12 +204,12 @@
 #define MSG_SQL_MISSING_SERVER "De server ontbreekt in het SQL configuratie bestand"
 #define MSG_SQL_DOWN "De SQL server lijkt niet actief te zijn"
 #define MSG_ILLEGAL_QUOTA "Ongeldige quota"
-#define MSG_QUOTA_FILES "%llu files in gebruik (%d%%) - goedgekeurd: %llu files"
+#define MSG_QUOTA_FILES "%llu Bestanden in gebruik (%d%%) - goedgekeurd: %llu bestanden"
 #define MSG_QUOTA_SIZE "%llu Kbytes in gebruik (%d%%) - goedgekeurd: %llu Kb"
 #define MSG_QUOTA_EXCEEDED "Quota overschreden: %s worden niet opgeslagen"
 #define MSG_AUTH_UNKNOWN "Onbekende autorisatie methode"
-#define MSG_PDB_BROKEN "Unable to read the indexed puredb file (or old format detected) - Try pure-pw mkdb"
-#define MSG_ALIASES_ALIAS "%s is an alias for %s."
-#define MSG_ALIASES_UNKNOWN "Unknown alias %s."
-#define MSG_ALIASES_BROKEN_FILE "Damaged aliases file"
-#define MSG_ALIASES_LIST "The following aliases are available :"
+#define MSG_PDB_BROKEN "Kan het geindexeerde  puredb bestand niet lezen (of oud formaat gedetecteerd) - Probeer pure-pw mkdb"
+#define MSG_ALIASES_ALIAS "%s is een alias voor %s."
+#define MSG_ALIASES_UNKNOWN "Onbekende alias %s."
+#define MSG_ALIASES_BROKEN_FILE "Beschadigd aliassen bestand"
+#define MSG_ALIASES_LIST "De volgende aliassen zijn beschikbaar :"
