@@ -73,10 +73,12 @@ static void dodaemonize(void)
 
 static int init(void)
 {
+#ifndef NON_ROOT_FTP
     if (geteuid() != (uid_t) 0) {
         fprintf(stderr, "Sorry, but you have to be r00t to run this program\n");
         return -1;
     }
+#endif
     
     return 0;
 }
@@ -162,14 +164,16 @@ static int parseoptions(int argc, char *argv[])
 
 static int changeuidgid(void)
 {
-    if (
-#ifdef HAVE_SETGROUPS
+#ifndef NON_ROOT_FTP
+    if (        
+# ifdef HAVE_SETGROUPS
         setgroups(1U, &gid) ||
-#endif
+# endif
         setgid(gid) || setegid(gid) ||
         setuid(uid) || seteuid(uid) || chdir("/")) {
         return -1;
     }
+#endif
     return 0;
 }
 
@@ -302,7 +306,7 @@ static void process(const int clientfd)
     
     while ((readen = read(clientfd, line, sizeof line - 1U)) < (ssize_t) 0 &&
            errno == EINTR);
-    if (readen == (ssize_t) 0) {
+    if (readen <= (ssize_t) 0) {
         return;
     }
     line[readen] = 0;
@@ -310,6 +314,11 @@ static void process(const int clientfd)
         return;
     }
     pid = fork();
+    if (pid == (pid_t) -1) {
+        close(pfds[0]);
+        close(pfds[1]);
+        return;
+    }    
     if (pid != (pid_t) 0) {
         close(pfds[1]);         /* close the output side of the pipe */
         if ((readen = safe_read(pfds[0], line, 
@@ -324,11 +333,6 @@ static void process(const int clientfd)
         close(pfds[0]);
         return;
     }
-    if (pid == (pid_t) -1) {
-        close(pfds[0]);
-        close(pfds[1]);
-        return;
-    }
     /* now, we are in the child */
     close(clientfd);
     close(kindy);
