@@ -643,9 +643,11 @@ int main(int argc, char *argv[])
         }
         if (fstat(mmap_fd, &st) != 0 || !S_ISREG(st.st_mode) ||
             (st.st_mode & 0600) != 0600 || 
-            st.st_size != (off_t) sizeof (FTPWhoEntry)
-#ifndef NON_ROOT_FTP
-            || st.st_uid != (uid_t) 0
+            st.st_size != (off_t) sizeof (FTPWhoEntry) ||
+#ifdef NON_ROOT_FTP
+            st.st_uid != geteuid()
+#else
+            st.st_uid != (uid_t) 0
 #endif
             ) {
             goto nextone;
