@@ -38,7 +38,12 @@ static int upload_pipe_ropen(void)
     setcloexec(upload_pipe_fd);
     if (fstat(upload_pipe_fd, &st) < 0 ||
         (st.st_mode & 0777) != 0600 || !S_ISFIFO(st.st_mode) ||
-        st.st_uid != (uid_t) 0) {
+#ifdef NON_ROOT_FTP
+        st.st_uid != geteuid()
+#else
+        st.st_uid != (uid_t) 0
+#endif
+        ) {
         fprintf(stderr, "Insecure permissions on " UPLOAD_PIPE_FILE "\n");
         return -1;
     }
@@ -179,10 +184,12 @@ static void dodaemonize(void)
 static int init(void)
 {
     (void) close(0);
+#ifndef NON_ROOT_FTP
     if (geteuid() != (uid_t) 0) {
         fprintf(stderr, "Sorry, but you have to be r00t to run this program\n");
         return -1;
     }
+#endif
     
     return 0;
 }
@@ -262,6 +269,7 @@ static int parseoptions(int argc, char *argv[])
 
 static int changeuidgid(void)
 {
+#ifndef NON_ROOT_FTP    
     if (
 #ifdef HAVE_SETGROUPS
         setgroups(1U, &gid) ||
@@ -270,6 +278,7 @@ static int changeuidgid(void)
         setuid(uid) || seteuid(uid) || chdir("/")) {
         return -1;
     }
+#endif
     return 0;
 }
 
